@@ -7,11 +7,12 @@ Robert Hijmans
 April 2016
 */
 
-using namespace std;
 #include <vector>
 #include <algorithm>
-#include <cmath>
-#include "SimUtil.h"
+#include <cmath> 
+#include <string> 
+
+#include "qUtil.h"
 #include "quefts.h"
 
 
@@ -183,13 +184,20 @@ void QueftsModel::run() {
 }
 
 
-
-std::vector<double> QueftsModel::runbatch(std::vector<double> Ns, std::vector<double> Ps, std::vector<double> Ks, std::vector<double> Ya) {
+// for spatial
+std::vector<double> QueftsModel::runbatch(std::vector<double> Ns, std::vector<double> Ps, std::vector<double> Ks, std::vector<double> Ya, std::string var) {
+	
+	size_t nout = 1;
+	bool gap = false;
+	if (var == "gap") {
+		nout = 3;
+		gap = true;
+	}
 	
 	size_t n = Ns.size();
-	std::vector<double> out(n, NAN); 
+	std::vector<double> out(n * nout, NAN); 
 	for (size_t i=0; i<n; i++) {
-		if (isnan(Ns[i])) continue;	
+		if (std::isnan(Ns[i])) continue;	
 		soil.N_base_supply = Ns[i];
 		soil.P_base_supply = Ps[i];
 		soil.K_base_supply = Ks[i];
@@ -197,7 +205,13 @@ std::vector<double> QueftsModel::runbatch(std::vector<double> Ns, std::vector<do
 		leaf_att = 0.45 * store_att;
 		stem_att = 0.55 * store_att;
 		run();
-		out[i] = store_lim;
+		if (gap) {
+			out[i*3] = N_gap;
+			out[i*3+1] = P_gap;
+			out[i*3+2] = K_gap;
+		} else {
+			out[i] = store_lim;
+		}
 	}
 	return out;
 }	
